==> haskell-monad-journal-0.7.2-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.2
id: monad-journal-0.7.2-Cv21fCiS3Tt1lbKPFn5Qbh
key: monad-journal-0.7.2-Cv21fCiS3Tt1lbKPFn5Qbh
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
abi: 085a80056a08ffae5dbbe15505878adc
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/monad-journal-0.7.2
hs-libraries: HSmonad-journal-0.7.2-Cv21fCiS3Tt1lbKPFn5Qbh
depends:
    base-4.9.0.0 either-4.4.1.1-9JVRXO1hxwop7BCTXURzs
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-journal-0.7.2-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-monad-journal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-journal
version: 0.7.2
id: monad-journal-0.7.2-LdzJ97MJz5972dk8ynYKRG
key: monad-journal-0.7.2-LdzJ97MJz5972dk8ynYKRG
license: BSD3
maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
homepage: http://github.com/phaazon/monad-journal
synopsis: Pure logger typeclass and monad transformer
description:
    This package provides a typeclass for logging in
    pure code, or more generally, in any kind of
    context. You can do whatever you want with
    logs, especially get them, clear them or even
    sink them through '\''IO'\'' if you'\''re logging in
    @(MonadIO m) => m@.
category: Control
author: Dimitri Sabadie <dimitri.sabadie@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Journal Control.Monad.Journal.Class
    Control.Monad.Trans.Journal
abi: 7290375346065f441eda4803ba3c996b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/monad-journal-0.7.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/monad-journal-0.7.2
hs-libraries: HSmonad-journal-0.7.2-LdzJ97MJz5972dk8ynYKRG
depends:
    base-4.9.0.0 either-4.4.1.1-5f7aE9WqhDuIG4WZ3BCho5
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
haddock-interfaces: /usr/share/doc/haskell-monad-journal/html/monad-journal.haddock
haddock-html: /usr/share/doc/haskell-monad-journal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
